src.imagedata.archives package
==============================

Submodules
----------

src.imagedata.archives.abstractarchive module
---------------------------------------------

.. automodule:: src.imagedata.archives.abstractarchive
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.archives.filesystemarchive module
-----------------------------------------------

.. automodule:: src.imagedata.archives.filesystemarchive
   :members:
   :undoc-members:
   :show-inheritance:

src.imagedata.archives.zipfilearchive module
--------------------------------------------

.. automodule:: src.imagedata.archives.zipfilearchive
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src.imagedata.archives
   :members:
   :undoc-members:
   :show-inheritance:
